# BSK Zephyr Python Library
Asynchronous Python library to control BSK Zephyr heat recovery devices using BSK Connect APIs. Published to PyPI `pip install bskzephyr` - https://pypi.org/project/bskzephyr/

Currently exposes mininmal set of API calls to support the Home Assistant custom component, [hass-bskzephyr](https://github.com/andersonshatch/hass-bskzephyr).

See [`test_bsk_zephyr.py`](test_bsk_zephyr.py) for some example use.
